@@ -6,9 +6,7 @@ import sys
 sys.path.append("../../")
 
 from nginqcomm.common import enums
-
-sys.path.append("../")
-from utils import maths
+from nginqcomm.utils import maths
 
 # @brief 报价币的数量转换为张数（size）
 #        如 币对 BTC-USDT-SWAP  中的 U数量转换为 BTC的张数(size)
